@@ -11,8 +11,6 @@ Authors:
 # std imports
 
 # 3rd party imports
-from django.conf import settings
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.db import models
 from django.http import HttpResponse, Http404
 from django.shortcuts import get_object_or_404, render_to_response
